"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.serverless.functions.v1.function_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetFunctionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTION_ID_FIELD_NUMBER: builtins.int
    function_id: builtins.str
    """ID of the function to return.

    To get a function ID make a [FunctionService.List] request.
    """
    def __init__(
        self,
        *,
        function_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["function_id", b"function_id"]) -> None: ...

global___GetFunctionRequest = GetFunctionRequest

@typing.final
class GetFunctionVersionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTION_VERSION_ID_FIELD_NUMBER: builtins.int
    function_version_id: builtins.str
    """ID of the version to return.

    To get a version ID make a [FunctionService.ListVersions] request.
    """
    def __init__(
        self,
        *,
        function_version_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["function_version_id", b"function_version_id"]) -> None: ...

global___GetFunctionVersionRequest = GetFunctionVersionRequest

@typing.final
class GetFunctionVersionByTagRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTION_ID_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    function_id: builtins.str
    """ID of the function whose versions should be listed.

    To get a function ID use a [FunctionService.List] request.
    """
    tag: builtins.str
    """Version tag.

    To get the history of version tags make a [FunctionService.ListTagHistory] request.
    """
    def __init__(
        self,
        *,
        function_id: builtins.str = ...,
        tag: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["function_id", b"function_id", "tag", b"tag"]) -> None: ...

global___GetFunctionVersionByTagRequest = GetFunctionVersionByTagRequest

@typing.final
class ListFunctionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list functions in.

    To get a folder ID make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `pageSize`, the service returns a [ListFunctionsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.

    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `pageToken` to the
    [ListFunctionsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters functions listed in the response.

    The expression must specify:
    1. The field name. Currently filtering can only be applied to the [Function.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    Example of a filter: `name="my-function"`.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListFunctionsRequest = ListFunctionsRequest

@typing.final
class ListFunctionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListFunctionsRequest.page_size], use `nextPageToken` as the value
    for the [ListFunctionsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `nextPageToken` to continue paging through the results.
    """
    @property
    def functions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.serverless.functions.v1.function_pb2.Function]:
        """List of functions in the specified folder."""

    def __init__(
        self,
        *,
        functions: collections.abc.Iterable[yandex.cloud.serverless.functions.v1.function_pb2.Function] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["functions", b"functions", "next_page_token", b"next_page_token"]) -> None: ...

global___ListFunctionsResponse = ListFunctionsResponse

@typing.final
class CreateFunctionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a function in.

    To get a folder ID make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    name: builtins.str
    """Name of the function.
    The name must be unique within the folder.
    """
    description: builtins.str
    """Description of the function."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "folder_id", b"folder_id", "labels", b"labels", "name", b"name"]) -> None: ...

global___CreateFunctionRequest = CreateFunctionRequest

@typing.final
class CreateFunctionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTION_ID_FIELD_NUMBER: builtins.int
    function_id: builtins.str
    """ID of the function that is being created."""
    def __init__(
        self,
        *,
        function_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["function_id", b"function_id"]) -> None: ...

global___CreateFunctionMetadata = CreateFunctionMetadata

@typing.final
class UpdateFunctionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FUNCTION_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    function_id: builtins.str
    """ID of the function to update.

    To get a function ID make a [FunctionService.List] request.
    """
    name: builtins.str
    """New name for the function.
    The name must be unique within the folder.
    """
    description: builtins.str
    """New description for the function."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which attributes of the function should be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Function labels as `key:value` pairs.

        Existing set of labels is completely replaced by the provided set, so if you just want
        to add or remove a label, request the current set of labels with a [FunctionService.Get] request.
        """

    def __init__(
        self,
        *,
        function_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "function_id", b"function_id", "labels", b"labels", "name", b"name", "update_mask", b"update_mask"]) -> None: ...

global___UpdateFunctionRequest = UpdateFunctionRequest

@typing.final
class UpdateFunctionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTION_ID_FIELD_NUMBER: builtins.int
    function_id: builtins.str
    """ID of the function that is being updated."""
    def __init__(
        self,
        *,
        function_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["function_id", b"function_id"]) -> None: ...

global___UpdateFunctionMetadata = UpdateFunctionMetadata

@typing.final
class DeleteFunctionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTION_ID_FIELD_NUMBER: builtins.int
    function_id: builtins.str
    """ID of the function to delete.
    To get a function ID make a [FunctionService.List] request.
    """
    def __init__(
        self,
        *,
        function_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["function_id", b"function_id"]) -> None: ...

global___DeleteFunctionRequest = DeleteFunctionRequest

@typing.final
class DeleteFunctionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTION_ID_FIELD_NUMBER: builtins.int
    function_id: builtins.str
    """ID of the function that is being deleted."""
    def __init__(
        self,
        *,
        function_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["function_id", b"function_id"]) -> None: ...

global___DeleteFunctionMetadata = DeleteFunctionMetadata

@typing.final
class DeleteFunctionVersionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTION_VERSION_ID_FIELD_NUMBER: builtins.int
    FORCE_FIELD_NUMBER: builtins.int
    function_version_id: builtins.str
    """ID of the function's version to delete."""
    force: builtins.bool
    """Forces deletion of the version tags.

    If the value equals false and the function has tags with the selected version then request returns an error.
    """
    def __init__(
        self,
        *,
        function_version_id: builtins.str = ...,
        force: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["force", b"force", "function_version_id", b"function_version_id"]) -> None: ...

global___DeleteFunctionVersionRequest = DeleteFunctionVersionRequest

@typing.final
class DeleteFunctionVersionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTION_VERSION_ID_FIELD_NUMBER: builtins.int
    function_version_id: builtins.str
    """ID of the function's version is being deleted."""
    def __init__(
        self,
        *,
        function_version_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["function_version_id", b"function_version_id"]) -> None: ...

global___DeleteFunctionVersionMetadata = DeleteFunctionVersionMetadata

@typing.final
class ListRuntimesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListRuntimesRequest = ListRuntimesRequest

@typing.final
class ListRuntimesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RUNTIMES_FIELD_NUMBER: builtins.int
    @property
    def runtimes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Runtime environments available for the specified function."""

    def __init__(
        self,
        *,
        runtimes: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["runtimes", b"runtimes"]) -> None: ...

global___ListRuntimesResponse = ListRuntimesResponse

@typing.final
class ListFunctionsVersionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    FUNCTION_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list function versions for.
    To get a folder ID make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    function_id: builtins.str
    """ID of the function to list versions for.
    To get a function ID use a [FunctionService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available results
    is larger than `pageSize`, the service returns a [ListFunctionsVersionsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.

    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `pageToken` to the
    [ListFunctionsVersionsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.

    The expression must specify:
    1. The field name. Currently filtering can only be applied to the [Version.status] and [Version.runtime] fields.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    Example of a filter: `status="ACTIVE"`.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        function_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["folder_id", b"folder_id", "function_id", b"function_id", "id", b"id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "function_id", b"function_id", "id", b"id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["id", b"id"]) -> typing.Literal["folder_id", "function_id"] | None: ...

global___ListFunctionsVersionsRequest = ListFunctionsVersionsRequest

@typing.final
class ListFunctionsVersionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListFunctionsVersionsRequest.page_size], use `nextPageToken` as the value
    for the [ListFunctionsVersionsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `nextPageToken` to continue paging through the results.
    """
    @property
    def versions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.serverless.functions.v1.function_pb2.Version]:
        """List of versions for the specified folder or function."""

    def __init__(
        self,
        *,
        versions: collections.abc.Iterable[yandex.cloud.serverless.functions.v1.function_pb2.Version] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "versions", b"versions"]) -> None: ...

global___ListFunctionsVersionsResponse = ListFunctionsVersionsResponse

@typing.final
class ListFunctionOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTION_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    function_id: builtins.str
    """ID of the function to list operations for."""
    page_size: builtins.int
    """The maximum number of results per page that should be returned. If the number of available
    results is larger than `pageSize`, the service returns a [ListFunctionOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.

    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `pageToken` to the
    [ListFunctionOperationsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.

    The expression must specify:
    1. The field name. Currently filtering can be applied to the [operation.Operation.done], [operation.Operation.created_by] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    Examples of a filter: `done=false`, `created_by='John.Doe'`.
    """
    def __init__(
        self,
        *,
        function_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "function_id", b"function_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListFunctionOperationsRequest = ListFunctionOperationsRequest

@typing.final
class ListFunctionOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListFunctionOperationsRequest.page_size], use `nextPageToken` as the value
    for the [ListFunctionOperationsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `nextPageToken` to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified function."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListFunctionOperationsResponse = ListFunctionOperationsResponse

@typing.final
class CreateFunctionVersionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class EnvironmentEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing.final
    class NamedServiceAccountsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FUNCTION_ID_FIELD_NUMBER: builtins.int
    RUNTIME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ENTRYPOINT_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    EXECUTION_TIMEOUT_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    PACKAGE_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    CONNECTIVITY_FIELD_NUMBER: builtins.int
    NAMED_SERVICE_ACCOUNTS_FIELD_NUMBER: builtins.int
    SECRETS_FIELD_NUMBER: builtins.int
    LOG_OPTIONS_FIELD_NUMBER: builtins.int
    STORAGE_MOUNTS_FIELD_NUMBER: builtins.int
    ASYNC_INVOCATION_CONFIG_FIELD_NUMBER: builtins.int
    TMPFS_SIZE_FIELD_NUMBER: builtins.int
    CONCURRENCY_FIELD_NUMBER: builtins.int
    MOUNTS_FIELD_NUMBER: builtins.int
    METADATA_OPTIONS_FIELD_NUMBER: builtins.int
    function_id: builtins.str
    """ID of the function to create a version for.

    To get a function ID, make a [FunctionService.List] request.
    """
    runtime: builtins.str
    """Runtime environment for the version."""
    description: builtins.str
    """Description of the version"""
    entrypoint: builtins.str
    """Entrypoint of the version."""
    service_account_id: builtins.str
    """ID of the service account to associate with the version."""
    content: builtins.bytes
    """Content of the deployment package."""
    version_id: builtins.str
    """ID of the version to be copied from. Source version must belong to the same folder as the created version
    and the user must have read permissions to the source version.
    """
    tmpfs_size: builtins.int
    """Optional size of in-memory mounted /tmp directory in bytes.
    Available for versions with resources.memory greater or equal to 1024 MiB.

    0 or in range from 512 MiB to 3/4 of resources.memory.
    """
    concurrency: builtins.int
    """The maximum number of requests processed by a function instance at the same time"""
    @property
    def resources(self) -> yandex.cloud.serverless.functions.v1.function_pb2.Resources:
        """Resources allocated to the version."""

    @property
    def execution_timeout(self) -> google.protobuf.duration_pb2.Duration:
        """Timeout for the execution of the version.

        If the timeout is exceeded, Cloud Functions responds with a 504 HTTP code.
        """

    @property
    def package(self) -> yandex.cloud.serverless.functions.v1.function_pb2.Package:
        """Functions deployment package."""

    @property
    def environment(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Environment settings for the version."""

    @property
    def tag(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Function version tags. For details, see [Version tag](/docs/functions/concepts/function#tag)."""

    @property
    def connectivity(self) -> yandex.cloud.serverless.functions.v1.function_pb2.Connectivity:
        """Function version connectivity. If specified the version will be attached to specified network/subnet(s)."""

    @property
    def named_service_accounts(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Additional service accounts to be used by the version."""

    @property
    def secrets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.serverless.functions.v1.function_pb2.Secret]:
        """Yandex Lockbox secrets to be used by the version."""

    @property
    def log_options(self) -> yandex.cloud.serverless.functions.v1.function_pb2.LogOptions:
        """Options for logging from the function"""

    @property
    def storage_mounts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.serverless.functions.v1.function_pb2.StorageMount]:
        """S3 mounts to be used by the version."""

    @property
    def async_invocation_config(self) -> yandex.cloud.serverless.functions.v1.function_pb2.AsyncInvocationConfig:
        """Config for asynchronous invocations of the version"""

    @property
    def mounts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.serverless.functions.v1.function_pb2.Mount]:
        """Mounts to be used by the version."""

    @property
    def metadata_options(self) -> yandex.cloud.serverless.functions.v1.function_pb2.MetadataOptions:
        """Metadata options for the version."""

    def __init__(
        self,
        *,
        function_id: builtins.str = ...,
        runtime: builtins.str = ...,
        description: builtins.str = ...,
        entrypoint: builtins.str = ...,
        resources: yandex.cloud.serverless.functions.v1.function_pb2.Resources | None = ...,
        execution_timeout: google.protobuf.duration_pb2.Duration | None = ...,
        service_account_id: builtins.str = ...,
        package: yandex.cloud.serverless.functions.v1.function_pb2.Package | None = ...,
        content: builtins.bytes = ...,
        version_id: builtins.str = ...,
        environment: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        tag: collections.abc.Iterable[builtins.str] | None = ...,
        connectivity: yandex.cloud.serverless.functions.v1.function_pb2.Connectivity | None = ...,
        named_service_accounts: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        secrets: collections.abc.Iterable[yandex.cloud.serverless.functions.v1.function_pb2.Secret] | None = ...,
        log_options: yandex.cloud.serverless.functions.v1.function_pb2.LogOptions | None = ...,
        storage_mounts: collections.abc.Iterable[yandex.cloud.serverless.functions.v1.function_pb2.StorageMount] | None = ...,
        async_invocation_config: yandex.cloud.serverless.functions.v1.function_pb2.AsyncInvocationConfig | None = ...,
        tmpfs_size: builtins.int = ...,
        concurrency: builtins.int = ...,
        mounts: collections.abc.Iterable[yandex.cloud.serverless.functions.v1.function_pb2.Mount] | None = ...,
        metadata_options: yandex.cloud.serverless.functions.v1.function_pb2.MetadataOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["async_invocation_config", b"async_invocation_config", "connectivity", b"connectivity", "content", b"content", "execution_timeout", b"execution_timeout", "log_options", b"log_options", "metadata_options", b"metadata_options", "package", b"package", "package_source", b"package_source", "resources", b"resources", "version_id", b"version_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["async_invocation_config", b"async_invocation_config", "concurrency", b"concurrency", "connectivity", b"connectivity", "content", b"content", "description", b"description", "entrypoint", b"entrypoint", "environment", b"environment", "execution_timeout", b"execution_timeout", "function_id", b"function_id", "log_options", b"log_options", "metadata_options", b"metadata_options", "mounts", b"mounts", "named_service_accounts", b"named_service_accounts", "package", b"package", "package_source", b"package_source", "resources", b"resources", "runtime", b"runtime", "secrets", b"secrets", "service_account_id", b"service_account_id", "storage_mounts", b"storage_mounts", "tag", b"tag", "tmpfs_size", b"tmpfs_size", "version_id", b"version_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["package_source", b"package_source"]) -> typing.Literal["package", "content", "version_id"] | None: ...

global___CreateFunctionVersionRequest = CreateFunctionVersionRequest

@typing.final
class CreateFunctionVersionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTION_VERSION_ID_FIELD_NUMBER: builtins.int
    function_version_id: builtins.str
    """ID of the version that is being created."""
    def __init__(
        self,
        *,
        function_version_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["function_version_id", b"function_version_id"]) -> None: ...

global___CreateFunctionVersionMetadata = CreateFunctionVersionMetadata

@typing.final
class SetFunctionTagRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTION_VERSION_ID_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    function_version_id: builtins.str
    """ID of the version to set the tag for.

    To get a version ID make a [FunctionService.ListVersions] request.
    """
    tag: builtins.str
    """Tag to set for the version."""
    def __init__(
        self,
        *,
        function_version_id: builtins.str = ...,
        tag: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["function_version_id", b"function_version_id", "tag", b"tag"]) -> None: ...

global___SetFunctionTagRequest = SetFunctionTagRequest

@typing.final
class RemoveFunctionTagRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTION_VERSION_ID_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    function_version_id: builtins.str
    """ID of the version to remove a tag from.

    To get the a version ID make a [FunctionService.ListVersions] request.
    """
    tag: builtins.str
    """Tag to remove from the specified version."""
    def __init__(
        self,
        *,
        function_version_id: builtins.str = ...,
        tag: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["function_version_id", b"function_version_id", "tag", b"tag"]) -> None: ...

global___RemoveFunctionTagRequest = RemoveFunctionTagRequest

@typing.final
class SetFunctionTagMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTION_VERSION_ID_FIELD_NUMBER: builtins.int
    function_version_id: builtins.str
    """ID of the function versions that is being tagged."""
    def __init__(
        self,
        *,
        function_version_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["function_version_id", b"function_version_id"]) -> None: ...

global___SetFunctionTagMetadata = SetFunctionTagMetadata

@typing.final
class RemoveFunctionTagMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTION_VERSION_ID_FIELD_NUMBER: builtins.int
    function_version_id: builtins.str
    """ID of the function versions that is being untagged."""
    def __init__(
        self,
        *,
        function_version_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["function_version_id", b"function_version_id"]) -> None: ...

global___RemoveFunctionTagMetadata = RemoveFunctionTagMetadata

@typing.final
class ListFunctionTagHistoryRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTION_ID_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    function_id: builtins.str
    """ID of the function to retrieve tag history for.

    To get a function ID, make a [FunctionService.List] request.
    """
    tag: builtins.str
    """Specific tag that history should be limited to."""
    page_size: builtins.int
    """The maximum number of results per page that should be returned. If the number of available
    results is larger than `pageSize`, the service returns a [ListFunctionOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `pageToken` to the
    [ListFunctionOperationsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.

    The expression must specify:
    1. The field name. Currently filtering can only be applied to the [FunctionTagHistoryRecord.effective_from] and [FunctionTagHistoryRecord.effective_to] fields.
    2. An `=` or `>` or `<` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    For example, `effective_to>2021-01-01T12:00:00Z`.
    """
    def __init__(
        self,
        *,
        function_id: builtins.str = ...,
        tag: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "function_id", b"function_id", "page_size", b"page_size", "page_token", b"page_token", "tag", b"tag"]) -> None: ...

global___ListFunctionTagHistoryRequest = ListFunctionTagHistoryRequest

@typing.final
class ListFunctionTagHistoryResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class FunctionTagHistoryRecord(google.protobuf.message.Message):
        """A record in the tag history."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        FUNCTION_ID_FIELD_NUMBER: builtins.int
        FUNCTION_VERSION_ID_FIELD_NUMBER: builtins.int
        TAG_FIELD_NUMBER: builtins.int
        EFFECTIVE_FROM_FIELD_NUMBER: builtins.int
        EFFECTIVE_TO_FIELD_NUMBER: builtins.int
        function_id: builtins.str
        """ID of the function that the record is about."""
        function_version_id: builtins.str
        """ID of the function version that the record is about."""
        tag: builtins.str
        """Tag that was set for the version at some point."""
        @property
        def effective_from(self) -> google.protobuf.timestamp_pb2.Timestamp:
            """Timestamp when the tag started being active for the function."""

        @property
        def effective_to(self) -> google.protobuf.timestamp_pb2.Timestamp:
            """Timestamp when the tag stopped being active for the function."""

        def __init__(
            self,
            *,
            function_id: builtins.str = ...,
            function_version_id: builtins.str = ...,
            tag: builtins.str = ...,
            effective_from: google.protobuf.timestamp_pb2.Timestamp | None = ...,
            effective_to: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["effective_from", b"effective_from", "effective_to", b"effective_to"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["effective_from", b"effective_from", "effective_to", b"effective_to", "function_id", b"function_id", "function_version_id", b"function_version_id", "tag", b"tag"]) -> None: ...

    FUNCTION_TAG_HISTORY_RECORD_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListFunctionTagHistoryRequest.page_size], use `nextPageToken` as the value
    for the [ListFunctionTagHistoryRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `nextPageToken` to continue paging through the results.
    """
    @property
    def function_tag_history_record(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ListFunctionTagHistoryResponse.FunctionTagHistoryRecord]:
        """Set of relevant tag history records."""

    def __init__(
        self,
        *,
        function_tag_history_record: collections.abc.Iterable[global___ListFunctionTagHistoryResponse.FunctionTagHistoryRecord] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["function_tag_history_record", b"function_tag_history_record", "next_page_token", b"next_page_token"]) -> None: ...

global___ListFunctionTagHistoryResponse = ListFunctionTagHistoryResponse

@typing.final
class ListScalingPoliciesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTION_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    function_id: builtins.str
    """ID of the function to retrieve scaling policies for.

    To get a function ID, make a [FunctionService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page that should be returned. If the number of available
    results is larger than `pageSize`, the service returns a [ListScalingPoliciesResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.

    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `pageToken` to the
    [ListScalingPoliciesResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        function_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["function_id", b"function_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListScalingPoliciesRequest = ListScalingPoliciesRequest

@typing.final
class ListScalingPoliciesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCALING_POLICIES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListScalingPoliciesRequest.page_size], use `nextPageToken` as the value
    for the [ListScalingPoliciesRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `nextPageToken` to continue paging through the results.
    """
    @property
    def scaling_policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.serverless.functions.v1.function_pb2.ScalingPolicy]:
        """Set of relevant scaling policies."""

    def __init__(
        self,
        *,
        scaling_policies: collections.abc.Iterable[yandex.cloud.serverless.functions.v1.function_pb2.ScalingPolicy] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "scaling_policies", b"scaling_policies"]) -> None: ...

global___ListScalingPoliciesResponse = ListScalingPoliciesResponse

@typing.final
class SetScalingPolicyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTION_ID_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    PROVISIONED_INSTANCES_COUNT_FIELD_NUMBER: builtins.int
    ZONE_INSTANCES_LIMIT_FIELD_NUMBER: builtins.int
    ZONE_REQUESTS_LIMIT_FIELD_NUMBER: builtins.int
    function_id: builtins.str
    """ID of the function to retrieve scaling policies for.

    To get a function ID, make a [FunctionService.List] request.
    """
    tag: builtins.str
    """Version tag.

    To get the history of version tags make a [FunctionService.ListTagHistory] request.
    """
    provisioned_instances_count: builtins.int
    """Minimum guaranteed provisioned instances count for all zones in total.
    Billed separately.
    """
    zone_instances_limit: builtins.int
    """Upper limit for instance count in each zone.
    0 means no limit.
    """
    zone_requests_limit: builtins.int
    """Upper limit of requests count in each zone.
    0 means no limit.
    """
    def __init__(
        self,
        *,
        function_id: builtins.str = ...,
        tag: builtins.str = ...,
        provisioned_instances_count: builtins.int = ...,
        zone_instances_limit: builtins.int = ...,
        zone_requests_limit: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["function_id", b"function_id", "provisioned_instances_count", b"provisioned_instances_count", "tag", b"tag", "zone_instances_limit", b"zone_instances_limit", "zone_requests_limit", b"zone_requests_limit"]) -> None: ...

global___SetScalingPolicyRequest = SetScalingPolicyRequest

@typing.final
class SetScalingPolicyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTION_ID_FIELD_NUMBER: builtins.int
    function_id: builtins.str
    """ID of the function for which scaling policy was set."""
    def __init__(
        self,
        *,
        function_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["function_id", b"function_id"]) -> None: ...

global___SetScalingPolicyMetadata = SetScalingPolicyMetadata

@typing.final
class RemoveScalingPolicyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTION_ID_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    function_id: builtins.str
    """ID of the function to remove scaling policies for.

    To get a function ID, make a [FunctionService.List] request.
    """
    tag: builtins.str
    """Version tag.

    To get the history of version tags make a [FunctionService.ListTagHistory] request.
    """
    def __init__(
        self,
        *,
        function_id: builtins.str = ...,
        tag: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["function_id", b"function_id", "tag", b"tag"]) -> None: ...

global___RemoveScalingPolicyRequest = RemoveScalingPolicyRequest

@typing.final
class RemoveScalingPolicyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTION_ID_FIELD_NUMBER: builtins.int
    function_id: builtins.str
    """ID of the function for which scaling policy was removed."""
    def __init__(
        self,
        *,
        function_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["function_id", b"function_id"]) -> None: ...

global___RemoveScalingPolicyMetadata = RemoveScalingPolicyMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.k8s.v1.maintenance_pb2
import yandex.cloud.k8s.v1.version_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ReleaseChannel:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ReleaseChannelEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ReleaseChannel.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    RELEASE_CHANNEL_UNSPECIFIED: _ReleaseChannel.ValueType  # 0
    RAPID: _ReleaseChannel.ValueType  # 1
    """Minor updates with new functions and improvements are often added.
    You can't disable automatic updates in this channel, but you can specify a time period for automatic updates.
    """
    REGULAR: _ReleaseChannel.ValueType  # 2
    """New functions and improvements are added in chunks shortly after they appear on `RAPID`."""
    STABLE: _ReleaseChannel.ValueType  # 3
    """Only updates related to bug fixes or security improvements are added."""

class ReleaseChannel(_ReleaseChannel, metaclass=_ReleaseChannelEnumTypeWrapper): ...

RELEASE_CHANNEL_UNSPECIFIED: ReleaseChannel.ValueType  # 0
RAPID: ReleaseChannel.ValueType  # 1
"""Minor updates with new functions and improvements are often added.
You can't disable automatic updates in this channel, but you can specify a time period for automatic updates.
"""
REGULAR: ReleaseChannel.ValueType  # 2
"""New functions and improvements are added in chunks shortly after they appear on `RAPID`."""
STABLE: ReleaseChannel.ValueType  # 3
"""Only updates related to bug fixes or security improvements are added."""
global___ReleaseChannel = ReleaseChannel

@typing.final
class Cluster(google.protobuf.message.Message):
    """A Kubernetes cluster."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Cluster._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Cluster._Status.ValueType  # 0
        PROVISIONING: Cluster._Status.ValueType  # 1
        """Kubernetes cluster is waiting for resources to be allocated."""
        RUNNING: Cluster._Status.ValueType  # 2
        """Kubernetes cluster is running."""
        RECONCILING: Cluster._Status.ValueType  # 3
        """Kubernetes cluster is being reconciled."""
        STOPPING: Cluster._Status.ValueType  # 4
        """Kubernetes cluster is being stopped."""
        STOPPED: Cluster._Status.ValueType  # 5
        """Kubernetes cluster stopped."""
        DELETING: Cluster._Status.ValueType  # 6
        """Kubernetes cluster is being deleted."""
        STARTING: Cluster._Status.ValueType  # 7
        """Kubernetes cluster is being started."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: Cluster.Status.ValueType  # 0
    PROVISIONING: Cluster.Status.ValueType  # 1
    """Kubernetes cluster is waiting for resources to be allocated."""
    RUNNING: Cluster.Status.ValueType  # 2
    """Kubernetes cluster is running."""
    RECONCILING: Cluster.Status.ValueType  # 3
    """Kubernetes cluster is being reconciled."""
    STOPPING: Cluster.Status.ValueType  # 4
    """Kubernetes cluster is being stopped."""
    STOPPED: Cluster.Status.ValueType  # 5
    """Kubernetes cluster stopped."""
    DELETING: Cluster.Status.ValueType  # 6
    """Kubernetes cluster is being deleted."""
    STARTING: Cluster.Status.ValueType  # 7
    """Kubernetes cluster is being started."""

    class _Health:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _HealthEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Cluster._Health.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        HEALTH_UNSPECIFIED: Cluster._Health.ValueType  # 0
        HEALTHY: Cluster._Health.ValueType  # 1
        """Kubernetes cluster is alive and well."""
        UNHEALTHY: Cluster._Health.ValueType  # 2
        """Kubernetes cluster is inoperable."""

    class Health(_Health, metaclass=_HealthEnumTypeWrapper): ...
    HEALTH_UNSPECIFIED: Cluster.Health.ValueType  # 0
    HEALTHY: Cluster.Health.ValueType  # 1
    """Kubernetes cluster is alive and well."""
    UNHEALTHY: Cluster.Health.ValueType  # 2
    """Kubernetes cluster is inoperable."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    HEALTH_FIELD_NUMBER: builtins.int
    NETWORK_ID_FIELD_NUMBER: builtins.int
    MASTER_FIELD_NUMBER: builtins.int
    IP_ALLOCATION_POLICY_FIELD_NUMBER: builtins.int
    GATEWAY_IPV4_ADDRESS_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    NODE_SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    NETWORK_POLICY_FIELD_NUMBER: builtins.int
    KMS_PROVIDER_FIELD_NUMBER: builtins.int
    LOG_GROUP_ID_FIELD_NUMBER: builtins.int
    CILIUM_FIELD_NUMBER: builtins.int
    SCHEDULED_MAINTENANCE_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the Kubernetes cluster."""
    folder_id: builtins.str
    """ID of the folder that the Kubernetes cluster belongs to."""
    name: builtins.str
    """Name of the Kubernetes cluster."""
    description: builtins.str
    """Description of the Kubernetes cluster. 0-256 characters long."""
    status: global___Cluster.Status.ValueType
    """Status of the Kubernetes cluster."""
    health: global___Cluster.Health.ValueType
    """Health of the Kubernetes cluster."""
    network_id: builtins.str
    """ID of the network the Kubernetes cluster belongs to."""
    gateway_ipv4_address: builtins.str
    """Gateway IPv4 address."""
    service_account_id: builtins.str
    """Service account to be used for provisioning Compute Cloud and VPC resources for Kubernetes cluster."""
    node_service_account_id: builtins.str
    """Service account to be used by the worker nodes of the Kubernetes cluster to access Container Registry or to push node logs and metrics."""
    release_channel: global___ReleaseChannel.ValueType
    """When creating a Kubernetes cluster, you should specify one of three release channels. The release channel contains several Kubernetes versions.
    Channels differ in the set of available versions, the management of auto-updates, and the updates received.
    You can't change the channel once the Kubernetes cluster is created, you can only recreate the Kubernetes cluster and specify a new release channel.
    For more details see [documentation](/docs/managed-kubernetes/concepts/release-channels-and-updates).
    """
    log_group_id: builtins.str
    """Log group where cluster stores cluster system logs, like audit, events, or controlplane logs."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs. Maximum of 64 per resource."""

    @property
    def master(self) -> global___Master:
        """Properties of the master for the Kubernetes cluster."""

    @property
    def ip_allocation_policy(self) -> global___IPAllocationPolicy:
        """Allocation policy for IP addresses of services and pods inside the Kubernetes cluster in different availability zones."""

    @property
    def network_policy(self) -> global___NetworkPolicy: ...
    @property
    def kms_provider(self) -> global___KMSProvider:
        """KMS provider configuration."""

    @property
    def cilium(self) -> global___Cilium: ...
    @property
    def scheduled_maintenance(self) -> yandex.cloud.k8s.v1.maintenance_pb2.ScheduledMaintenance: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        status: global___Cluster.Status.ValueType = ...,
        health: global___Cluster.Health.ValueType = ...,
        network_id: builtins.str = ...,
        master: global___Master | None = ...,
        ip_allocation_policy: global___IPAllocationPolicy | None = ...,
        gateway_ipv4_address: builtins.str = ...,
        service_account_id: builtins.str = ...,
        node_service_account_id: builtins.str = ...,
        release_channel: global___ReleaseChannel.ValueType = ...,
        network_policy: global___NetworkPolicy | None = ...,
        kms_provider: global___KMSProvider | None = ...,
        log_group_id: builtins.str = ...,
        cilium: global___Cilium | None = ...,
        scheduled_maintenance: yandex.cloud.k8s.v1.maintenance_pb2.ScheduledMaintenance | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cilium", b"cilium", "created_at", b"created_at", "gateway_ipv4_address", b"gateway_ipv4_address", "internet_gateway", b"internet_gateway", "ip_allocation_policy", b"ip_allocation_policy", "kms_provider", b"kms_provider", "master", b"master", "network_implementation", b"network_implementation", "network_policy", b"network_policy", "scheduled_maintenance", b"scheduled_maintenance"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cilium", b"cilium", "created_at", b"created_at", "description", b"description", "folder_id", b"folder_id", "gateway_ipv4_address", b"gateway_ipv4_address", "health", b"health", "id", b"id", "internet_gateway", b"internet_gateway", "ip_allocation_policy", b"ip_allocation_policy", "kms_provider", b"kms_provider", "labels", b"labels", "log_group_id", b"log_group_id", "master", b"master", "name", b"name", "network_id", b"network_id", "network_implementation", b"network_implementation", "network_policy", b"network_policy", "node_service_account_id", b"node_service_account_id", "release_channel", b"release_channel", "scheduled_maintenance", b"scheduled_maintenance", "service_account_id", b"service_account_id", "status", b"status"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["internet_gateway", b"internet_gateway"]) -> typing.Literal["gateway_ipv4_address"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["network_implementation", b"network_implementation"]) -> typing.Literal["cilium"] | None: ...

global___Cluster = Cluster

@typing.final
class Master(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ZONAL_MASTER_FIELD_NUMBER: builtins.int
    REGIONAL_MASTER_FIELD_NUMBER: builtins.int
    LOCATIONS_FIELD_NUMBER: builtins.int
    ETCD_CLUSTER_SIZE_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    ENDPOINTS_FIELD_NUMBER: builtins.int
    MASTER_AUTH_FIELD_NUMBER: builtins.int
    VERSION_INFO_FIELD_NUMBER: builtins.int
    MAINTENANCE_POLICY_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    MASTER_LOGGING_FIELD_NUMBER: builtins.int
    etcd_cluster_size: builtins.int
    """Number of etcd nodes in cluster."""
    version: builtins.str
    """Version of Kubernetes components that runs on the master."""
    @property
    def zonal_master(self) -> global___ZonalMaster:
        """Parameters of the availability zone for the master."""

    @property
    def regional_master(self) -> global___RegionalMaster:
        """Parameters of the region for the master."""

    @property
    def locations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Location]:
        """Locations specification for Kubernetes control-plane (master) instances."""

    @property
    def endpoints(self) -> global___MasterEndpoints:
        """Endpoints of the master. Endpoints constitute of scheme and port (i.e. `https://ip-address:port`)
        and can be used by the clients to communicate with the Kubernetes API of the Kubernetes cluster.
        """

    @property
    def master_auth(self) -> global___MasterAuth:
        """Master authentication parameters are used to establish trust between the master and a client."""

    @property
    def version_info(self) -> yandex.cloud.k8s.v1.version_pb2.VersionInfo:
        """Detailed information about the Kubernetes version that is running on the master."""

    @property
    def maintenance_policy(self) -> global___MasterMaintenancePolicy:
        """Maintenance policy of the master."""

    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Master security groups."""

    @property
    def master_logging(self) -> global___MasterLogging:
        """Cloud Logging for master components."""

    def __init__(
        self,
        *,
        zonal_master: global___ZonalMaster | None = ...,
        regional_master: global___RegionalMaster | None = ...,
        locations: collections.abc.Iterable[global___Location] | None = ...,
        etcd_cluster_size: builtins.int = ...,
        version: builtins.str = ...,
        endpoints: global___MasterEndpoints | None = ...,
        master_auth: global___MasterAuth | None = ...,
        version_info: yandex.cloud.k8s.v1.version_pb2.VersionInfo | None = ...,
        maintenance_policy: global___MasterMaintenancePolicy | None = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        master_logging: global___MasterLogging | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["endpoints", b"endpoints", "maintenance_policy", b"maintenance_policy", "master_auth", b"master_auth", "master_logging", b"master_logging", "master_type", b"master_type", "regional_master", b"regional_master", "version_info", b"version_info", "zonal_master", b"zonal_master"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["endpoints", b"endpoints", "etcd_cluster_size", b"etcd_cluster_size", "locations", b"locations", "maintenance_policy", b"maintenance_policy", "master_auth", b"master_auth", "master_logging", b"master_logging", "master_type", b"master_type", "regional_master", b"regional_master", "security_group_ids", b"security_group_ids", "version", b"version", "version_info", b"version_info", "zonal_master", b"zonal_master"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["master_type", b"master_type"]) -> typing.Literal["zonal_master", "regional_master"] | None: ...

global___Master = Master

@typing.final
class MasterAuth(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_CA_CERTIFICATE_FIELD_NUMBER: builtins.int
    cluster_ca_certificate: builtins.str
    """PEM-encoded public certificate that is the root of trust for the Kubernetes cluster."""
    def __init__(
        self,
        *,
        cluster_ca_certificate: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_ca_certificate", b"cluster_ca_certificate"]) -> None: ...

global___MasterAuth = MasterAuth

@typing.final
class ZonalMaster(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ZONE_ID_FIELD_NUMBER: builtins.int
    INTERNAL_V4_ADDRESS_FIELD_NUMBER: builtins.int
    EXTERNAL_V4_ADDRESS_FIELD_NUMBER: builtins.int
    zone_id: builtins.str
    """ID of the availability zone where the master resides."""
    internal_v4_address: builtins.str
    """IPv4 internal network address that is assigned to the master."""
    external_v4_address: builtins.str
    """IPv4 external network address that is assigned to the master."""
    def __init__(
        self,
        *,
        zone_id: builtins.str = ...,
        internal_v4_address: builtins.str = ...,
        external_v4_address: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["external_v4_address", b"external_v4_address", "internal_v4_address", b"internal_v4_address", "zone_id", b"zone_id"]) -> None: ...

global___ZonalMaster = ZonalMaster

@typing.final
class RegionalMaster(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGION_ID_FIELD_NUMBER: builtins.int
    INTERNAL_V4_ADDRESS_FIELD_NUMBER: builtins.int
    EXTERNAL_V4_ADDRESS_FIELD_NUMBER: builtins.int
    EXTERNAL_V6_ADDRESS_FIELD_NUMBER: builtins.int
    region_id: builtins.str
    """ID of the region where the master resides."""
    internal_v4_address: builtins.str
    """IPv4 internal network address that is assigned to the master."""
    external_v4_address: builtins.str
    """IPv4 external network address that is assigned to the master."""
    external_v6_address: builtins.str
    """IPv6 external network address that is assigned to the master."""
    def __init__(
        self,
        *,
        region_id: builtins.str = ...,
        internal_v4_address: builtins.str = ...,
        external_v4_address: builtins.str = ...,
        external_v6_address: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["external_v4_address", b"external_v4_address", "external_v6_address", b"external_v6_address", "internal_v4_address", b"internal_v4_address", "region_id", b"region_id"]) -> None: ...

global___RegionalMaster = RegionalMaster

@typing.final
class Location(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ZONE_ID_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    zone_id: builtins.str
    """ID of the availability zone where the master resides."""
    subnet_id: builtins.str
    """ID of the VPC network's subnet where the master resides."""
    def __init__(
        self,
        *,
        zone_id: builtins.str = ...,
        subnet_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["subnet_id", b"subnet_id", "zone_id", b"zone_id"]) -> None: ...

global___Location = Location

@typing.final
class MasterEndpoints(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INTERNAL_V4_ENDPOINT_FIELD_NUMBER: builtins.int
    EXTERNAL_V4_ENDPOINT_FIELD_NUMBER: builtins.int
    EXTERNAL_V6_ENDPOINT_FIELD_NUMBER: builtins.int
    internal_v4_endpoint: builtins.str
    """Internal endpoint that can be used to connect to the master from cloud networks."""
    external_v4_endpoint: builtins.str
    """External endpoint that can be used to access Kubernetes cluster API from the internet (outside of the cloud)."""
    external_v6_endpoint: builtins.str
    """External IPv6 endpoint that can be used to access Kubernetes cluster API from the internet (outside of the cloud)."""
    def __init__(
        self,
        *,
        internal_v4_endpoint: builtins.str = ...,
        external_v4_endpoint: builtins.str = ...,
        external_v6_endpoint: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["external_v4_endpoint", b"external_v4_endpoint", "external_v6_endpoint", b"external_v6_endpoint", "internal_v4_endpoint", b"internal_v4_endpoint"]) -> None: ...

global___MasterEndpoints = MasterEndpoints

@typing.final
class IPAllocationPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_IPV4_CIDR_BLOCK_FIELD_NUMBER: builtins.int
    NODE_IPV4_CIDR_MASK_SIZE_FIELD_NUMBER: builtins.int
    SERVICE_IPV4_CIDR_BLOCK_FIELD_NUMBER: builtins.int
    CLUSTER_IPV6_CIDR_BLOCK_FIELD_NUMBER: builtins.int
    SERVICE_IPV6_CIDR_BLOCK_FIELD_NUMBER: builtins.int
    cluster_ipv4_cidr_block: builtins.str
    """CIDR block. IP range for allocating pod addresses.

    It should not overlap with any subnet in the network the Kubernetes cluster located in. Static routes will be
    set up for this CIDR blocks in node subnets.
    """
    node_ipv4_cidr_mask_size: builtins.int
    """Size of the masks that are assigned for each node in the cluster.

    If not specified, 24 is used.
    """
    service_ipv4_cidr_block: builtins.str
    """CIDR block. IP range Kubernetes service Kubernetes cluster IP addresses will be allocated from.

    It should not overlap with any subnet in the network the Kubernetes cluster located in.
    """
    cluster_ipv6_cidr_block: builtins.str
    """IPv6 range for allocating pod IP addresses."""
    service_ipv6_cidr_block: builtins.str
    """IPv6 range for allocating Kubernetes service IP addresses"""
    def __init__(
        self,
        *,
        cluster_ipv4_cidr_block: builtins.str = ...,
        node_ipv4_cidr_mask_size: builtins.int = ...,
        service_ipv4_cidr_block: builtins.str = ...,
        cluster_ipv6_cidr_block: builtins.str = ...,
        service_ipv6_cidr_block: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_ipv4_cidr_block", b"cluster_ipv4_cidr_block", "cluster_ipv6_cidr_block", b"cluster_ipv6_cidr_block", "node_ipv4_cidr_mask_size", b"node_ipv4_cidr_mask_size", "service_ipv4_cidr_block", b"service_ipv4_cidr_block", "service_ipv6_cidr_block", b"service_ipv6_cidr_block"]) -> None: ...

global___IPAllocationPolicy = IPAllocationPolicy

@typing.final
class MasterMaintenancePolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTO_UPGRADE_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    auto_upgrade: builtins.bool
    """If set to true, automatic updates are installed in the specified period of time with no interaction from the user.
    If set to false, automatic upgrades are disabled.
    """
    @property
    def maintenance_window(self) -> yandex.cloud.k8s.v1.maintenance_pb2.MaintenanceWindow:
        """Maintenance window settings. Update will start at the specified time and last no more than the specified duration.
        The time is set in UTC.
        """

    def __init__(
        self,
        *,
        auto_upgrade: builtins.bool = ...,
        maintenance_window: yandex.cloud.k8s.v1.maintenance_pb2.MaintenanceWindow | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["maintenance_window", b"maintenance_window"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auto_upgrade", b"auto_upgrade", "maintenance_window", b"maintenance_window"]) -> None: ...

global___MasterMaintenancePolicy = MasterMaintenancePolicy

@typing.final
class MasterLogging(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    LOG_GROUP_ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    AUDIT_ENABLED_FIELD_NUMBER: builtins.int
    CLUSTER_AUTOSCALER_ENABLED_FIELD_NUMBER: builtins.int
    KUBE_APISERVER_ENABLED_FIELD_NUMBER: builtins.int
    EVENTS_ENABLED_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    """Identifies whether Cloud Logging is enabled for master components."""
    log_group_id: builtins.str
    """ID of the log group where logs of master components should be stored."""
    folder_id: builtins.str
    """ID of the folder where logs should be stored (in default group)."""
    audit_enabled: builtins.bool
    """Identifies whether Cloud Logging is enabled for audit logs."""
    cluster_autoscaler_enabled: builtins.bool
    """Identifies whether Cloud Logging is enabled for cluster-autoscaler."""
    kube_apiserver_enabled: builtins.bool
    """Identifies whether Cloud Logging is enabled for kube-apiserver."""
    events_enabled: builtins.bool
    """Identifies whether Cloud Logging is enabled for events."""
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
        log_group_id: builtins.str = ...,
        folder_id: builtins.str = ...,
        audit_enabled: builtins.bool = ...,
        cluster_autoscaler_enabled: builtins.bool = ...,
        kube_apiserver_enabled: builtins.bool = ...,
        events_enabled: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["destination", b"destination", "folder_id", b"folder_id", "log_group_id", b"log_group_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["audit_enabled", b"audit_enabled", "cluster_autoscaler_enabled", b"cluster_autoscaler_enabled", "destination", b"destination", "enabled", b"enabled", "events_enabled", b"events_enabled", "folder_id", b"folder_id", "kube_apiserver_enabled", b"kube_apiserver_enabled", "log_group_id", b"log_group_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["destination", b"destination"]) -> typing.Literal["log_group_id", "folder_id"] | None: ...

global___MasterLogging = MasterLogging

@typing.final
class NetworkPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Provider:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ProviderEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[NetworkPolicy._Provider.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        PROVIDER_UNSPECIFIED: NetworkPolicy._Provider.ValueType  # 0
        CALICO: NetworkPolicy._Provider.ValueType  # 1

    class Provider(_Provider, metaclass=_ProviderEnumTypeWrapper): ...
    PROVIDER_UNSPECIFIED: NetworkPolicy.Provider.ValueType  # 0
    CALICO: NetworkPolicy.Provider.ValueType  # 1

    PROVIDER_FIELD_NUMBER: builtins.int
    provider: global___NetworkPolicy.Provider.ValueType
    def __init__(
        self,
        *,
        provider: global___NetworkPolicy.Provider.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["provider", b"provider"]) -> None: ...

global___NetworkPolicy = NetworkPolicy

@typing.final
class KMSProvider(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """KMS key ID for secrets encryption.
    To obtain a KMS key ID use a [yandex.cloud.kms.v1.SymmetricKeyService.List] request.
    """
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key_id", b"key_id"]) -> None: ...

global___KMSProvider = KMSProvider

@typing.final
class Cilium(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _RoutingMode:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _RoutingModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Cilium._RoutingMode.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ROUTING_MODE_UNSPECIFIED: Cilium._RoutingMode.ValueType  # 0
        TUNNEL: Cilium._RoutingMode.ValueType  # 1

    class RoutingMode(_RoutingMode, metaclass=_RoutingModeEnumTypeWrapper): ...
    ROUTING_MODE_UNSPECIFIED: Cilium.RoutingMode.ValueType  # 0
    TUNNEL: Cilium.RoutingMode.ValueType  # 1

    ROUTING_MODE_FIELD_NUMBER: builtins.int
    routing_mode: global___Cilium.RoutingMode.ValueType
    def __init__(
        self,
        *,
        routing_mode: global___Cilium.RoutingMode.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["routing_mode", b"routing_mode"]) -> None: ...

global___Cilium = Cilium



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/mysql/v1/user.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/mysql/v1/user.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$yandex/cloud/mdb/mysql/v1/user.proto\x12\x19yandex.cloud.mdb.mysql.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\x85\x03\n\x04User\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12:\n\x0bpermissions\x18\x03 \x03(\x0b\x32%.yandex.cloud.mdb.mysql.v1.Permission\x12G\n\x12global_permissions\x18\x04 \x03(\x0e\x32+.yandex.cloud.mdb.mysql.v1.GlobalPermission\x12\x46\n\x11\x63onnection_limits\x18\x05 \x01(\x0b\x32+.yandex.cloud.mdb.mysql.v1.ConnectionLimits\x12\x44\n\x15\x61uthentication_plugin\x18\x06 \x01(\x0e\x32%.yandex.cloud.mdb.mysql.v1.AuthPlugin\x12H\n\x12\x63onnection_manager\x18\x07 \x01(\x0b\x32,.yandex.cloud.mdb.mysql.v1.ConnectionManager\"\xaf\x03\n\nPermission\x12\x15\n\rdatabase_name\x18\x01 \x01(\t\x12G\n\x05roles\x18\x02 \x03(\x0e\x32/.yandex.cloud.mdb.mysql.v1.Permission.PrivilegeB\x07\x82\xc8\x31\x03>=1\"\xc0\x02\n\tPrivilege\x12\x19\n\x15PRIVILEGE_UNSPECIFIED\x10\x00\x12\x12\n\x0e\x41LL_PRIVILEGES\x10\x01\x12\t\n\x05\x41LTER\x10\x02\x12\x11\n\rALTER_ROUTINE\x10\x03\x12\n\n\x06\x43REATE\x10\x04\x12\x12\n\x0e\x43REATE_ROUTINE\x10\x05\x12\x1b\n\x17\x43REATE_TEMPORARY_TABLES\x10\x06\x12\x0f\n\x0b\x43REATE_VIEW\x10\x07\x12\n\n\x06\x44\x45LETE\x10\x08\x12\x08\n\x04\x44ROP\x10\t\x12\t\n\x05\x45VENT\x10\n\x12\x0b\n\x07\x45XECUTE\x10\x0b\x12\t\n\x05INDEX\x10\x0c\x12\n\n\x06INSERT\x10\r\x12\x0f\n\x0bLOCK_TABLES\x10\x0e\x12\n\n\x06SELECT\x10\x0f\x12\r\n\tSHOW_VIEW\x10\x10\x12\x0b\n\x07TRIGGER\x10\x11\x12\n\n\x06UPDATE\x10\x12\x12\x0e\n\nREFERENCES\x10\x13\"\xa8\x02\n\x10\x43onnectionLimits\x12\x44\n\x16max_questions_per_hour\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x42\n\x14max_updates_per_hour\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x46\n\x18max_connections_per_hour\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x42\n\x14max_user_connections\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\"*\n\x11\x43onnectionManager\x12\x15\n\rconnection_id\x18\x01 \x01(\t\"\xa3\x03\n\x08UserSpec\x12,\n\x04name\x18\x01 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=32\x12\x1f\n\x08password\x18\x02 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x38-128\x12:\n\x0bpermissions\x18\x03 \x03(\x0b\x32%.yandex.cloud.mdb.mysql.v1.Permission\x12G\n\x12global_permissions\x18\x04 \x03(\x0e\x32+.yandex.cloud.mdb.mysql.v1.GlobalPermission\x12\x46\n\x11\x63onnection_limits\x18\x05 \x01(\x0b\x32+.yandex.cloud.mdb.mysql.v1.ConnectionLimits\x12\x44\n\x15\x61uthentication_plugin\x18\x06 \x01(\x0e\x32%.yandex.cloud.mdb.mysql.v1.AuthPlugin\x12\x35\n\x11generate_password\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue*\x9e\x01\n\x10GlobalPermission\x12!\n\x1dGLOBAL_PERMISSION_UNSPECIFIED\x10\x00\x12\x16\n\x12REPLICATION_CLIENT\x10\x01\x12\x15\n\x11REPLICATION_SLAVE\x10\x02\x12\x0b\n\x07PROCESS\x10\x03\x12\x19\n\x15\x46LUSH_OPTIMIZER_COSTS\x10\x04\x12\x10\n\x0cSHOW_ROUTINE\x10\x05*\x9f\x01\n\nAuthPlugin\x12\x1b\n\x17\x41UTH_PLUGIN_UNSPECIFIED\x10\x00\x12\x19\n\x15MYSQL_NATIVE_PASSWORD\x10\x01\x12\x19\n\x15\x43\x41\x43HING_SHA2_PASSWORD\x10\x02\x12\x13\n\x0fSHA256_PASSWORD\x10\x03\x12\x12\n\x0eMYSQL_NO_LOGIN\x10\x04\x12\x15\n\x11MDB_IAMPROXY_AUTH\x10\x05\x42\x64\n\x1dyandex.cloud.api.mdb.mysql.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mysql/v1;mysqlb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.mysql.v1.user_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035yandex.cloud.api.mdb.mysql.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mysql/v1;mysql'
  _globals['_PERMISSION'].fields_by_name['roles']._loaded_options = None
  _globals['_PERMISSION'].fields_by_name['roles']._serialized_options = b'\202\3101\003>=1'
  _globals['_CONNECTIONLIMITS'].fields_by_name['max_questions_per_hour']._loaded_options = None
  _globals['_CONNECTIONLIMITS'].fields_by_name['max_questions_per_hour']._serialized_options = b'\372\3071\003>=0'
  _globals['_CONNECTIONLIMITS'].fields_by_name['max_updates_per_hour']._loaded_options = None
  _globals['_CONNECTIONLIMITS'].fields_by_name['max_updates_per_hour']._serialized_options = b'\372\3071\003>=0'
  _globals['_CONNECTIONLIMITS'].fields_by_name['max_connections_per_hour']._loaded_options = None
  _globals['_CONNECTIONLIMITS'].fields_by_name['max_connections_per_hour']._serialized_options = b'\372\3071\003>=0'
  _globals['_CONNECTIONLIMITS'].fields_by_name['max_user_connections']._loaded_options = None
  _globals['_CONNECTIONLIMITS'].fields_by_name['max_user_connections']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSPEC'].fields_by_name['name']._loaded_options = None
  _globals['_USERSPEC'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=32'
  _globals['_USERSPEC'].fields_by_name['password']._loaded_options = None
  _globals['_USERSPEC'].fields_by_name['password']._serialized_options = b'\350\3071\001\212\3101\0058-128'
  _globals['_GLOBALPERMISSION']._serialized_start=1722
  _globals['_GLOBALPERMISSION']._serialized_end=1880
  _globals['_AUTHPLUGIN']._serialized_start=1883
  _globals['_AUTHPLUGIN']._serialized_end=2042
  _globals['_USER']._serialized_start=131
  _globals['_USER']._serialized_end=520
  _globals['_PERMISSION']._serialized_start=523
  _globals['_PERMISSION']._serialized_end=954
  _globals['_PERMISSION_PRIVILEGE']._serialized_start=634
  _globals['_PERMISSION_PRIVILEGE']._serialized_end=954
  _globals['_CONNECTIONLIMITS']._serialized_start=957
  _globals['_CONNECTIONLIMITS']._serialized_end=1253
  _globals['_CONNECTIONMANAGER']._serialized_start=1255
  _globals['_CONNECTIONMANAGER']._serialized_end=1297
  _globals['_USERSPEC']._serialized_start=1300
  _globals['_USERSPEC']._serialized_end=1719
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Connection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    GATEWAY_ID_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    CONNECTED_AT_FIELD_NUMBER: builtins.int
    LAST_ACTIVE_AT_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the connection."""
    gateway_id: builtins.str
    """ID of the API Gateway."""
    @property
    def identity(self) -> global___Identity:
        """The information about the caller making the request to API Gateway."""

    @property
    def connected_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The timestamp at which connection was established."""

    @property
    def last_active_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The timestamp at which connection was last accessed."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        gateway_id: builtins.str = ...,
        identity: global___Identity | None = ...,
        connected_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_active_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["connected_at", b"connected_at", "identity", b"identity", "last_active_at", b"last_active_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["connected_at", b"connected_at", "gateway_id", b"gateway_id", "id", b"id", "identity", b"identity", "last_active_at", b"last_active_at"]) -> None: ...

global___Connection = Connection

@typing.final
class Identity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_IP_FIELD_NUMBER: builtins.int
    USER_AGENT_FIELD_NUMBER: builtins.int
    source_ip: builtins.str
    """The source IP address of the caller making the request to API Gateway."""
    user_agent: builtins.str
    """The User Agent of the caller making the request to API Gateway."""
    def __init__(
        self,
        *,
        source_ip: builtins.str = ...,
        user_agent: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["source_ip", b"source_ip", "user_agent", b"user_agent"]) -> None: ...

global___Identity = Identity



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class AddMetricRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPUTE_INSTANCE_ID_FIELD_NUMBER: builtins.int
    JOB_ID_FIELD_NUMBER: builtins.int
    CHUNKS_FIELD_NUMBER: builtins.int
    AGENT_INSTANCE_ID_FIELD_NUMBER: builtins.int
    compute_instance_id: builtins.str
    job_id: builtins.str
    agent_instance_id: builtins.str
    @property
    def chunks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MetricChunk]: ...
    def __init__(
        self,
        *,
        compute_instance_id: builtins.str = ...,
        job_id: builtins.str = ...,
        chunks: collections.abc.Iterable[global___MetricChunk] | None = ...,
        agent_instance_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["agent_instance_id", b"agent_instance_id", "chunks", b"chunks", "compute_instance_id", b"compute_instance_id", "job_id", b"job_id"]) -> None: ...

global___AddMetricRequest = AddMetricRequest

@typing.final
class MetricChunk(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    COMMENT_FIELD_NUMBER: builtins.int
    INSTANCE_HOST_FIELD_NUMBER: builtins.int
    timestamp: builtins.int
    comment: builtins.str
    instance_host: builtins.str
    @property
    def data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Metric]: ...
    def __init__(
        self,
        *,
        data: collections.abc.Iterable[global___Metric] | None = ...,
        timestamp: builtins.int = ...,
        comment: builtins.str = ...,
        instance_host: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["comment", b"comment", "data", b"data", "instance_host", b"instance_host", "timestamp", b"timestamp"]) -> None: ...

global___MetricChunk = MetricChunk

@typing.final
class Metric(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    METRIC_TYPE_FIELD_NUMBER: builtins.int
    METRIC_NAME_FIELD_NUMBER: builtins.int
    METRIC_VALUE_FIELD_NUMBER: builtins.int
    metric_type: builtins.str
    metric_name: builtins.str
    metric_value: builtins.float
    def __init__(
        self,
        *,
        metric_type: builtins.str = ...,
        metric_name: builtins.str = ...,
        metric_value: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["metric_name", b"metric_name", "metric_type", b"metric_type", "metric_value", b"metric_value"]) -> None: ...

global___Metric = Metric

@typing.final
class AddMetricResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    METRIC_TRAIL_ID_FIELD_NUMBER: builtins.int
    CODE_FIELD_NUMBER: builtins.int
    metric_trail_id: builtins.str
    code: builtins.int
    def __init__(
        self,
        *,
        metric_trail_id: builtins.str = ...,
        code: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["code", b"code", "metric_trail_id", b"metric_trail_id"]) -> None: ...

global___AddMetricResponse = AddMetricResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/video/v1/video.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/video/v1/video.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!yandex/cloud/video/v1/video.proto\x12\x15yandex.cloud.video.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xb0\t\n\x05Video\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x14\n\x0cthumbnail_id\x18\x05 \x01(\t\x12\x38\n\x06status\x18\x06 \x01(\x0e\x32(.yandex.cloud.video.v1.Video.VideoStatus\x12\x15\n\rerror_message\x18\x12 \x01(\t\x12H\n\x11visibility_status\x18\t \x01(\x0e\x32-.yandex.cloud.video.v1.Video.VisibilityStatus\x12+\n\x08\x64uration\x18\x08 \x01(\x0b\x32\x19.google.protobuf.Duration\x12<\n\x0e\x61uto_transcode\x18\x0b \x01(\x0e\x32$.yandex.cloud.video.v1.AutoTranscode\x12-\n\tenable_ad\x18\x11 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x14\n\x0csubtitle_ids\x18\x0c \x03(\t\x12\x36\n\x08\x66\x65\x61tures\x18\r \x01(\x0b\x32$.yandex.cloud.video.v1.VideoFeatures\x12\x37\n\x04tusd\x18\xe8\x07 \x01(\x0b\x32&.yandex.cloud.video.v1.VideoTUSDSourceH\x00\x12H\n\rpublic_access\x18\xd0\x0f \x01(\x0b\x32..yandex.cloud.video.v1.VideoPublicAccessRightsH\x01\x12K\n\x0fsign_url_access\x18\xd3\x0f \x01(\x0b\x32/.yandex.cloud.video.v1.VideoSignURLAccessRightsH\x01\x12.\n\ncreated_at\x18\x64 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x65 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x06labels\x18\xc8\x01 \x03(\x0b\x32(.yandex.cloud.video.v1.Video.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x7f\n\x0bVideoStatus\x12\x1c\n\x18VIDEO_STATUS_UNSPECIFIED\x10\x00\x12\x12\n\x0eWAIT_UPLOADING\x10\x01\x12\x0c\n\x08UPLOADED\x10\x02\x12\x0e\n\nPROCESSING\x10\x04\x12\t\n\x05READY\x10\x05\x12\t\n\x05\x45RROR\x10\x07\"\x04\x08\x03\x10\x03\"\x04\x08\x06\x10\x06\"U\n\x10VisibilityStatus\x12!\n\x1dVISIBILITY_STATUS_UNSPECIFIED\x10\x00\x12\r\n\tPUBLISHED\x10\x01\x12\x0f\n\x0bUNPUBLISHED\x10\x02\x42\x08\n\x06sourceB\x0f\n\raccess_rightsJ\x06\x08\xd1\x0f\x10\xd2\x0fJ\x06\x08\xd2\x0f\x10\xd3\x0fJ\x04\x08\x07\x10\x08J\x04\x08\n\x10\x0bJ\x04\x08\x0e\x10\x11J\x04\x08\x13\x10\x64J\x05\x08\x66\x10\xc8\x01J\x06\x08\xc9\x01\x10\xe8\x07J\x06\x08\xe9\x07\x10\xd0\x0f\"1\n\x0fVideoTUSDSource\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x11\n\tfile_size\x18\x02 \x01(\x03\"\x19\n\x17VideoPublicAccessRights\"\x1a\n\x18VideoSignURLAccessRights\"\x9a\x03\n\rVideoFeatures\x12=\n\x07summary\x18\x01 \x01(\x0b\x32,.yandex.cloud.video.v1.VideoFeatures.Summary\x1a\xdc\x01\n\x07Summary\x12\x42\n\x06result\x18\x01 \x01(\x0e\x32\x32.yandex.cloud.video.v1.VideoFeatures.FeatureResult\x12\x45\n\x04urls\x18\x03 \x03(\x0b\x32\x37.yandex.cloud.video.v1.VideoFeatures.Summary.SummaryURL\x1a@\n\nSummaryURL\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x13\n\x0btrack_index\x18\x02 \x01(\x03\x12\x10\n\x08src_lang\x18\x03 \x01(\tJ\x04\x08\x02\x10\x03\"k\n\rFeatureResult\x12\x1e\n\x1a\x46\x45\x41TURE_RESULT_UNSPECIFIED\x10\x00\x12\x11\n\rNOT_REQUESTED\x10\x01\x12\x0e\n\nPROCESSING\x10\x02\x12\x0b\n\x07SUCCESS\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04*H\n\rAutoTranscode\x12\x1e\n\x1a\x41UTO_TRANSCODE_UNSPECIFIED\x10\x00\x12\n\n\x06\x45NABLE\x10\x01\x12\x0b\n\x07\x44ISABLE\x10\x02\x42\\\n\x19yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;videob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.video.v1.video_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;video'
  _globals['_VIDEO_LABELSENTRY']._loaded_options = None
  _globals['_VIDEO_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_AUTOTRANSCODE']._serialized_start=1879
  _globals['_AUTOTRANSCODE']._serialized_end=1951
  _globals['_VIDEO']._serialized_start=158
  _globals['_VIDEO']._serialized_end=1358
  _globals['_VIDEO_LABELSENTRY']._serialized_start=1007
  _globals['_VIDEO_LABELSENTRY']._serialized_end=1052
  _globals['_VIDEO_VIDEOSTATUS']._serialized_start=1054
  _globals['_VIDEO_VIDEOSTATUS']._serialized_end=1181
  _globals['_VIDEO_VISIBILITYSTATUS']._serialized_start=1183
  _globals['_VIDEO_VISIBILITYSTATUS']._serialized_end=1268
  _globals['_VIDEOTUSDSOURCE']._serialized_start=1360
  _globals['_VIDEOTUSDSOURCE']._serialized_end=1409
  _globals['_VIDEOPUBLICACCESSRIGHTS']._serialized_start=1411
  _globals['_VIDEOPUBLICACCESSRIGHTS']._serialized_end=1436
  _globals['_VIDEOSIGNURLACCESSRIGHTS']._serialized_start=1438
  _globals['_VIDEOSIGNURLACCESSRIGHTS']._serialized_end=1464
  _globals['_VIDEOFEATURES']._serialized_start=1467
  _globals['_VIDEOFEATURES']._serialized_end=1877
  _globals['_VIDEOFEATURES_SUMMARY']._serialized_start=1548
  _globals['_VIDEOFEATURES_SUMMARY']._serialized_end=1768
  _globals['_VIDEOFEATURES_SUMMARY_SUMMARYURL']._serialized_start=1698
  _globals['_VIDEOFEATURES_SUMMARY_SUMMARYURL']._serialized_end=1762
  _globals['_VIDEOFEATURES_FEATURERESULT']._serialized_start=1770
  _globals['_VIDEOFEATURES_FEATURERESULT']._serialized_end=1877
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.wrappers_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _GlobalPermission:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _GlobalPermissionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_GlobalPermission.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    GLOBAL_PERMISSION_UNSPECIFIED: _GlobalPermission.ValueType  # 0
    REPLICATION_CLIENT: _GlobalPermission.ValueType  # 1
    """Enables use of the `SHOW MASTER STATUS`, `SHOW SLAVE STATUS`, and `SHOW BINARY LOGS` statements."""
    REPLICATION_SLAVE: _GlobalPermission.ValueType  # 2
    """Enables the account to request updates that have been made to databases on the master server,
    using the `SHOW SLAVE HOSTS`, `SHOW RELAYLOG EVENTS` and `SHOW BINLOG EVENTS` statements.
    """
    PROCESS: _GlobalPermission.ValueType  # 3
    """Enables display of information about the the statements currently being performed by sessions (the set of threads executing within the server).

    The privilege enables use of `SHOW PROCESSLIST` or `mysqladmin` processlist to see threads belonging to other users.
    You can always see your own threads. The `PROCESS` privilege also enables use of `SHOW ENGINE`.
    """
    FLUSH_OPTIMIZER_COSTS: _GlobalPermission.ValueType  # 4
    """Enables use of the `FLUSH OPTIMIZER_COSTS` statement."""
    SHOW_ROUTINE: _GlobalPermission.ValueType  # 5
    """Enables a user to access definitions and properties of all stored routines (stored procedures and functions), even those for which the user is not named as the routine DEFINER.
    This access includes:
    The contents of the Information Schema `ROUTINES` table.
    The `SHOW CREATE FUNCTION` and `SHOW CREATE PROCEDURE` statements.
    The `SHOW FUNCTION CODE` and `SHOW PROCEDURE CODE` statements.
    The SHOW `FUNCTION STATUS` and `SHOW PROCEDURE STATUS` statements.
    """

class GlobalPermission(_GlobalPermission, metaclass=_GlobalPermissionEnumTypeWrapper): ...

GLOBAL_PERMISSION_UNSPECIFIED: GlobalPermission.ValueType  # 0
REPLICATION_CLIENT: GlobalPermission.ValueType  # 1
"""Enables use of the `SHOW MASTER STATUS`, `SHOW SLAVE STATUS`, and `SHOW BINARY LOGS` statements."""
REPLICATION_SLAVE: GlobalPermission.ValueType  # 2
"""Enables the account to request updates that have been made to databases on the master server,
using the `SHOW SLAVE HOSTS`, `SHOW RELAYLOG EVENTS` and `SHOW BINLOG EVENTS` statements.
"""
PROCESS: GlobalPermission.ValueType  # 3
"""Enables display of information about the the statements currently being performed by sessions (the set of threads executing within the server).

The privilege enables use of `SHOW PROCESSLIST` or `mysqladmin` processlist to see threads belonging to other users.
You can always see your own threads. The `PROCESS` privilege also enables use of `SHOW ENGINE`.
"""
FLUSH_OPTIMIZER_COSTS: GlobalPermission.ValueType  # 4
"""Enables use of the `FLUSH OPTIMIZER_COSTS` statement."""
SHOW_ROUTINE: GlobalPermission.ValueType  # 5
"""Enables a user to access definitions and properties of all stored routines (stored procedures and functions), even those for which the user is not named as the routine DEFINER.
This access includes:
The contents of the Information Schema `ROUTINES` table.
The `SHOW CREATE FUNCTION` and `SHOW CREATE PROCEDURE` statements.
The `SHOW FUNCTION CODE` and `SHOW PROCEDURE CODE` statements.
The SHOW `FUNCTION STATUS` and `SHOW PROCEDURE STATUS` statements.
"""
global___GlobalPermission = GlobalPermission

class _AuthPlugin:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AuthPluginEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AuthPlugin.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    AUTH_PLUGIN_UNSPECIFIED: _AuthPlugin.ValueType  # 0
    MYSQL_NATIVE_PASSWORD: _AuthPlugin.ValueType  # 1
    """Use [Native Pluggable Authentication](https://dev.mysql.com/doc/refman/8.0/en/native-pluggable-authentication.html)."""
    CACHING_SHA2_PASSWORD: _AuthPlugin.ValueType  # 2
    """Use [Caching SHA-2 Pluggable Authentication](https://dev.mysql.com/doc/refman/8.0/en/caching-sha2-pluggable-authentication.html)."""
    SHA256_PASSWORD: _AuthPlugin.ValueType  # 3
    """Use [SHA-256 Pluggable Authentication](https://dev.mysql.com/doc/refman/8.0/en/sha256-pluggable-authentication.html)."""
    MYSQL_NO_LOGIN: _AuthPlugin.ValueType  # 4
    """Use [MYSQL_NO_LOGIN Pluggable Authentication](https://dev.mysql.com/doc/refman/8.0/en/no-login-pluggable-authentication.html)."""
    MDB_IAMPROXY_AUTH: _AuthPlugin.ValueType  # 5
    """Use [IAM Pluggable Authentication](https://yandex.cloud/en/docs/iam/concepts/authorization/)."""

class AuthPlugin(_AuthPlugin, metaclass=_AuthPluginEnumTypeWrapper): ...

AUTH_PLUGIN_UNSPECIFIED: AuthPlugin.ValueType  # 0
MYSQL_NATIVE_PASSWORD: AuthPlugin.ValueType  # 1
"""Use [Native Pluggable Authentication](https://dev.mysql.com/doc/refman/8.0/en/native-pluggable-authentication.html)."""
CACHING_SHA2_PASSWORD: AuthPlugin.ValueType  # 2
"""Use [Caching SHA-2 Pluggable Authentication](https://dev.mysql.com/doc/refman/8.0/en/caching-sha2-pluggable-authentication.html)."""
SHA256_PASSWORD: AuthPlugin.ValueType  # 3
"""Use [SHA-256 Pluggable Authentication](https://dev.mysql.com/doc/refman/8.0/en/sha256-pluggable-authentication.html)."""
MYSQL_NO_LOGIN: AuthPlugin.ValueType  # 4
"""Use [MYSQL_NO_LOGIN Pluggable Authentication](https://dev.mysql.com/doc/refman/8.0/en/no-login-pluggable-authentication.html)."""
MDB_IAMPROXY_AUTH: AuthPlugin.ValueType  # 5
"""Use [IAM Pluggable Authentication](https://yandex.cloud/en/docs/iam/concepts/authorization/)."""
global___AuthPlugin = AuthPlugin

@typing.final
class User(google.protobuf.message.Message):
    """An object that represents MySQL user.

    See [the documentation](/docs/managed-mysql/operations/cluster-users) for details.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PERMISSIONS_FIELD_NUMBER: builtins.int
    GLOBAL_PERMISSIONS_FIELD_NUMBER: builtins.int
    CONNECTION_LIMITS_FIELD_NUMBER: builtins.int
    AUTHENTICATION_PLUGIN_FIELD_NUMBER: builtins.int
    CONNECTION_MANAGER_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the user."""
    cluster_id: builtins.str
    """ID of the cluster the user belongs to."""
    authentication_plugin: global___AuthPlugin.ValueType
    """User authentication plugin."""
    @property
    def permissions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Permission]:
        """Set of permissions granted to the user."""

    @property
    def global_permissions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___GlobalPermission.ValueType]:
        """Set of global permissions to grant to the user."""

    @property
    def connection_limits(self) -> global___ConnectionLimits:
        """Set of user connection limits."""

    @property
    def connection_manager(self) -> global___ConnectionManager:
        """Connection Manager Connection and settings associated with user. Read only field."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        cluster_id: builtins.str = ...,
        permissions: collections.abc.Iterable[global___Permission] | None = ...,
        global_permissions: collections.abc.Iterable[global___GlobalPermission.ValueType] | None = ...,
        connection_limits: global___ConnectionLimits | None = ...,
        authentication_plugin: global___AuthPlugin.ValueType = ...,
        connection_manager: global___ConnectionManager | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["connection_limits", b"connection_limits", "connection_manager", b"connection_manager"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["authentication_plugin", b"authentication_plugin", "cluster_id", b"cluster_id", "connection_limits", b"connection_limits", "connection_manager", b"connection_manager", "global_permissions", b"global_permissions", "name", b"name", "permissions", b"permissions"]) -> None: ...

global___User = User

@typing.final
class Permission(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Privilege:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _PrivilegeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Permission._Privilege.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        PRIVILEGE_UNSPECIFIED: Permission._Privilege.ValueType  # 0
        ALL_PRIVILEGES: Permission._Privilege.ValueType  # 1
        """All privileges that can be made available to the user."""
        ALTER: Permission._Privilege.ValueType  # 2
        """Altering tables."""
        ALTER_ROUTINE: Permission._Privilege.ValueType  # 3
        """Altering stored routines and functions."""
        CREATE: Permission._Privilege.ValueType  # 4
        """Creating tables or indexes."""
        CREATE_ROUTINE: Permission._Privilege.ValueType  # 5
        """Creating stored routines."""
        CREATE_TEMPORARY_TABLES: Permission._Privilege.ValueType  # 6
        """Creating temporary tables."""
        CREATE_VIEW: Permission._Privilege.ValueType  # 7
        """Creating views."""
        DELETE: Permission._Privilege.ValueType  # 8
        """Deleting tables."""
        DROP: Permission._Privilege.ValueType  # 9
        """Removing tables or views."""
        EVENT: Permission._Privilege.ValueType  # 10
        """Creating, altering, dropping, or displaying events for the Event Scheduler."""
        EXECUTE: Permission._Privilege.ValueType  # 11
        """Executing stored routines."""
        INDEX: Permission._Privilege.ValueType  # 12
        """Creating and removing indexes."""
        INSERT: Permission._Privilege.ValueType  # 13
        """Inserting rows into the database."""
        LOCK_TABLES: Permission._Privilege.ValueType  # 14
        """Using `LOCK TABLES` statement for tables available with `SELECT` privilege."""
        SELECT: Permission._Privilege.ValueType  # 15
        """Selecting rows from tables.

        Some `SELECT` statements can be allowed without the `SELECT` privilege. All statements that read column values require the `SELECT` privilege.

        See [MySQL documentation](https://dev.mysql.com/doc/refman/8.0/en/privileges-provided.html#priv_select) for details.
        """
        SHOW_VIEW: Permission._Privilege.ValueType  # 16
        """Using the `SHOW CREATE VIEW` statement. Also needed for views used with `EXPLAIN`."""
        TRIGGER: Permission._Privilege.ValueType  # 17
        """Creating, removing, executing, or displaying triggers for a table."""
        UPDATE: Permission._Privilege.ValueType  # 18
        """Updating rows in the database."""
        REFERENCES: Permission._Privilege.ValueType  # 19
        """Creation of a foreign key constraint for the parent table."""

    class Privilege(_Privilege, metaclass=_PrivilegeEnumTypeWrapper): ...
    PRIVILEGE_UNSPECIFIED: Permission.Privilege.ValueType  # 0
    ALL_PRIVILEGES: Permission.Privilege.ValueType  # 1
    """All privileges that can be made available to the user."""
    ALTER: Permission.Privilege.ValueType  # 2
    """Altering tables."""
    ALTER_ROUTINE: Permission.Privilege.ValueType  # 3
    """Altering stored routines and functions."""
    CREATE: Permission.Privilege.ValueType  # 4
    """Creating tables or indexes."""
    CREATE_ROUTINE: Permission.Privilege.ValueType  # 5
    """Creating stored routines."""
    CREATE_TEMPORARY_TABLES: Permission.Privilege.ValueType  # 6
    """Creating temporary tables."""
    CREATE_VIEW: Permission.Privilege.ValueType  # 7
    """Creating views."""
    DELETE: Permission.Privilege.ValueType  # 8
    """Deleting tables."""
    DROP: Permission.Privilege.ValueType  # 9
    """Removing tables or views."""
    EVENT: Permission.Privilege.ValueType  # 10
    """Creating, altering, dropping, or displaying events for the Event Scheduler."""
    EXECUTE: Permission.Privilege.ValueType  # 11
    """Executing stored routines."""
    INDEX: Permission.Privilege.ValueType  # 12
    """Creating and removing indexes."""
    INSERT: Permission.Privilege.ValueType  # 13
    """Inserting rows into the database."""
    LOCK_TABLES: Permission.Privilege.ValueType  # 14
    """Using `LOCK TABLES` statement for tables available with `SELECT` privilege."""
    SELECT: Permission.Privilege.ValueType  # 15
    """Selecting rows from tables.

    Some `SELECT` statements can be allowed without the `SELECT` privilege. All statements that read column values require the `SELECT` privilege.

    See [MySQL documentation](https://dev.mysql.com/doc/refman/8.0/en/privileges-provided.html#priv_select) for details.
    """
    SHOW_VIEW: Permission.Privilege.ValueType  # 16
    """Using the `SHOW CREATE VIEW` statement. Also needed for views used with `EXPLAIN`."""
    TRIGGER: Permission.Privilege.ValueType  # 17
    """Creating, removing, executing, or displaying triggers for a table."""
    UPDATE: Permission.Privilege.ValueType  # 18
    """Updating rows in the database."""
    REFERENCES: Permission.Privilege.ValueType  # 19
    """Creation of a foreign key constraint for the parent table."""

    DATABASE_NAME_FIELD_NUMBER: builtins.int
    ROLES_FIELD_NUMBER: builtins.int
    database_name: builtins.str
    """Name of the database that the permission grants access to."""
    @property
    def roles(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___Permission.Privilege.ValueType]:
        """Roles granted to the user within the database.

        See [the documentation](/docs/managed-mysql/operations/grant) for details.
        """

    def __init__(
        self,
        *,
        database_name: builtins.str = ...,
        roles: collections.abc.Iterable[global___Permission.Privilege.ValueType] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["database_name", b"database_name", "roles", b"roles"]) -> None: ...

global___Permission = Permission

@typing.final
class ConnectionLimits(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_QUESTIONS_PER_HOUR_FIELD_NUMBER: builtins.int
    MAX_UPDATES_PER_HOUR_FIELD_NUMBER: builtins.int
    MAX_CONNECTIONS_PER_HOUR_FIELD_NUMBER: builtins.int
    MAX_USER_CONNECTIONS_FIELD_NUMBER: builtins.int
    @property
    def max_questions_per_hour(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum permitted number of user questions per hour."""

    @property
    def max_updates_per_hour(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum permitted number of user updates per hour."""

    @property
    def max_connections_per_hour(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum permitted number of simultaneous client connections per hour."""

    @property
    def max_user_connections(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum number of simultaneous connections permitted to any given MySQL user account."""

    def __init__(
        self,
        *,
        max_questions_per_hour: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_updates_per_hour: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_connections_per_hour: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_user_connections: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["max_connections_per_hour", b"max_connections_per_hour", "max_questions_per_hour", b"max_questions_per_hour", "max_updates_per_hour", b"max_updates_per_hour", "max_user_connections", b"max_user_connections"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["max_connections_per_hour", b"max_connections_per_hour", "max_questions_per_hour", b"max_questions_per_hour", "max_updates_per_hour", b"max_updates_per_hour", "max_user_connections", b"max_user_connections"]) -> None: ...

global___ConnectionLimits = ConnectionLimits

@typing.final
class ConnectionManager(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTION_ID_FIELD_NUMBER: builtins.int
    connection_id: builtins.str
    """ID of Connection Manager Connection"""
    def __init__(
        self,
        *,
        connection_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["connection_id", b"connection_id"]) -> None: ...

global___ConnectionManager = ConnectionManager

@typing.final
class UserSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    PERMISSIONS_FIELD_NUMBER: builtins.int
    GLOBAL_PERMISSIONS_FIELD_NUMBER: builtins.int
    CONNECTION_LIMITS_FIELD_NUMBER: builtins.int
    AUTHENTICATION_PLUGIN_FIELD_NUMBER: builtins.int
    GENERATE_PASSWORD_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the user."""
    password: builtins.str
    """Password of the user."""
    authentication_plugin: global___AuthPlugin.ValueType
    """User authentication plugin."""
    @property
    def permissions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Permission]:
        """Set of permissions granted to the user to access specific databases.
        One permission per database.

        When a permission for a database is set, the user will have access to the database.
        """

    @property
    def global_permissions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___GlobalPermission.ValueType]:
        """Set of global permissions to grant to the user."""

    @property
    def connection_limits(self) -> global___ConnectionLimits:
        """Set of user connection limits."""

    @property
    def generate_password(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Generate password using Connection Manager."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        password: builtins.str = ...,
        permissions: collections.abc.Iterable[global___Permission] | None = ...,
        global_permissions: collections.abc.Iterable[global___GlobalPermission.ValueType] | None = ...,
        connection_limits: global___ConnectionLimits | None = ...,
        authentication_plugin: global___AuthPlugin.ValueType = ...,
        generate_password: google.protobuf.wrappers_pb2.BoolValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["connection_limits", b"connection_limits", "generate_password", b"generate_password"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["authentication_plugin", b"authentication_plugin", "connection_limits", b"connection_limits", "generate_password", b"generate_password", "global_permissions", b"global_permissions", "name", b"name", "password", b"password", "permissions", b"permissions"]) -> None: ...

global___UserSpec = UserSpec



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.ai.assistants.v1.assistant_pb2
import yandex.cloud.ai.assistants.v1.common_pb2
import yandex.cloud.ai.common.common_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CreateAssistantRequest(google.protobuf.message.Message):
    """Request to create a new assistant."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPIRATION_CONFIG_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    MODEL_URI_FIELD_NUMBER: builtins.int
    INSTRUCTION_FIELD_NUMBER: builtins.int
    PROMPT_TRUNCATION_OPTIONS_FIELD_NUMBER: builtins.int
    COMPLETION_OPTIONS_FIELD_NUMBER: builtins.int
    TOOLS_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    name: builtins.str
    """Name of the assistant."""
    description: builtins.str
    """Description of the assistant."""
    model_uri: builtins.str
    """The [ID of the model](/docs/foundation-models/concepts/yandexgpt/models) to be used for completion generation."""
    instruction: builtins.str
    """Instructions or guidelines that the assistant should follow when generating responses or performing tasks.
    These instructions can help guide the assistant's behavior and responses.
    """
    @property
    def expiration_config(self) -> yandex.cloud.ai.common.common_pb2.ExpirationConfig:
        """Expiration configuration for the assistant."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Set of key-value pairs to label the user."""

    @property
    def prompt_truncation_options(self) -> yandex.cloud.ai.assistants.v1.common_pb2.PromptTruncationOptions:
        """Configuration options for truncating the prompt when the token count exceeds a specified limit."""

    @property
    def completion_options(self) -> yandex.cloud.ai.assistants.v1.common_pb2.CompletionOptions:
        """Configuration options for completion generation."""

    @property
    def tools(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.ai.assistants.v1.common_pb2.Tool]:
        """List of tools that the assistant can use to perform additional tasks.
        One example is the SearchIndexTool, which is used for Retrieval-Augmented Generation (RAG).
        """

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        expiration_config: yandex.cloud.ai.common.common_pb2.ExpirationConfig | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        model_uri: builtins.str = ...,
        instruction: builtins.str = ...,
        prompt_truncation_options: yandex.cloud.ai.assistants.v1.common_pb2.PromptTruncationOptions | None = ...,
        completion_options: yandex.cloud.ai.assistants.v1.common_pb2.CompletionOptions | None = ...,
        tools: collections.abc.Iterable[yandex.cloud.ai.assistants.v1.common_pb2.Tool] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["completion_options", b"completion_options", "expiration_config", b"expiration_config", "prompt_truncation_options", b"prompt_truncation_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["completion_options", b"completion_options", "description", b"description", "expiration_config", b"expiration_config", "folder_id", b"folder_id", "instruction", b"instruction", "labels", b"labels", "model_uri", b"model_uri", "name", b"name", "prompt_truncation_options", b"prompt_truncation_options", "tools", b"tools"]) -> None: ...

global___CreateAssistantRequest = CreateAssistantRequest

@typing.final
class GetAssistantRequest(google.protobuf.message.Message):
    """Request message for retrieving an assistant by ID."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ASSISTANT_ID_FIELD_NUMBER: builtins.int
    assistant_id: builtins.str
    """ID of the assistant to retrieve."""
    def __init__(
        self,
        *,
        assistant_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["assistant_id", b"assistant_id"]) -> None: ...

global___GetAssistantRequest = GetAssistantRequest

@typing.final
class UpdateAssistantRequest(google.protobuf.message.Message):
    """Request message for updating an existing assistant."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ASSISTANT_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPIRATION_CONFIG_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    MODEL_URI_FIELD_NUMBER: builtins.int
    INSTRUCTION_FIELD_NUMBER: builtins.int
    PROMPT_TRUNCATION_OPTIONS_FIELD_NUMBER: builtins.int
    COMPLETION_OPTIONS_FIELD_NUMBER: builtins.int
    TOOLS_FIELD_NUMBER: builtins.int
    assistant_id: builtins.str
    """ID of the assistant to update."""
    name: builtins.str
    """New name for the assistant."""
    description: builtins.str
    """New description for the assistant."""
    model_uri: builtins.str
    """The new [ID of the model](/docs/foundation-models/concepts/yandexgpt/models) to be used for completion generation."""
    instruction: builtins.str
    """New instructions or guidelines for the assistant to follow."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask specifying which fields to update."""

    @property
    def expiration_config(self) -> yandex.cloud.ai.common.common_pb2.ExpirationConfig:
        """New expiration configuration for the assistant."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """New set of labels for the assistant."""

    @property
    def prompt_truncation_options(self) -> yandex.cloud.ai.assistants.v1.common_pb2.PromptTruncationOptions:
        """New configuration for truncating the prompt."""

    @property
    def completion_options(self) -> yandex.cloud.ai.assistants.v1.common_pb2.CompletionOptions:
        """New configuration for completion generation."""

    @property
    def tools(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.ai.assistants.v1.common_pb2.Tool]:
        """New list of tools the assistant can use."""

    def __init__(
        self,
        *,
        assistant_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        expiration_config: yandex.cloud.ai.common.common_pb2.ExpirationConfig | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        model_uri: builtins.str = ...,
        instruction: builtins.str = ...,
        prompt_truncation_options: yandex.cloud.ai.assistants.v1.common_pb2.PromptTruncationOptions | None = ...,
        completion_options: yandex.cloud.ai.assistants.v1.common_pb2.CompletionOptions | None = ...,
        tools: collections.abc.Iterable[yandex.cloud.ai.assistants.v1.common_pb2.Tool] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["completion_options", b"completion_options", "expiration_config", b"expiration_config", "prompt_truncation_options", b"prompt_truncation_options", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["assistant_id", b"assistant_id", "completion_options", b"completion_options", "description", b"description", "expiration_config", b"expiration_config", "instruction", b"instruction", "labels", b"labels", "model_uri", b"model_uri", "name", b"name", "prompt_truncation_options", b"prompt_truncation_options", "tools", b"tools", "update_mask", b"update_mask"]) -> None: ...

global___UpdateAssistantRequest = UpdateAssistantRequest

@typing.final
class DeleteAssistantRequest(google.protobuf.message.Message):
    """Request message for deleting an assistant by ID."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ASSISTANT_ID_FIELD_NUMBER: builtins.int
    assistant_id: builtins.str
    """ID of the assistant to delete."""
    def __init__(
        self,
        *,
        assistant_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["assistant_id", b"assistant_id"]) -> None: ...

global___DeleteAssistantRequest = DeleteAssistantRequest

@typing.final
class DeleteAssistantResponse(google.protobuf.message.Message):
    """Response message for the delete operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteAssistantResponse = DeleteAssistantResponse

@typing.final
class ListAssistantsRequest(google.protobuf.message.Message):
    """Request message for listing assistants in a specific folder."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """Folder ID from which to list assistants."""
    page_size: builtins.int
    """Maximum number of assistants to return per page."""
    page_token: builtins.str
    """Token to retrieve the next page of results."""
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListAssistantsRequest = ListAssistantsRequest

@typing.final
class ListAssistantsResponse(google.protobuf.message.Message):
    """Response message for the list operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ASSISTANTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token to retrieve the next page of results."""
    @property
    def assistants(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.ai.assistants.v1.assistant_pb2.Assistant]:
        """List of assistants in the specified folder."""

    def __init__(
        self,
        *,
        assistants: collections.abc.Iterable[yandex.cloud.ai.assistants.v1.assistant_pb2.Assistant] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["assistants", b"assistants", "next_page_token", b"next_page_token"]) -> None: ...

global___ListAssistantsResponse = ListAssistantsResponse

@typing.final
class ListAssistantVersionsRequest(google.protobuf.message.Message):
    """Request to list all versions of a specific assistant."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ASSISTANT_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    assistant_id: builtins.str
    """ID of the assistant whose versions are to be listed."""
    page_size: builtins.int
    """Maximum number of versions to return per page."""
    page_token: builtins.str
    """Token to retrieve the next page of results."""
    def __init__(
        self,
        *,
        assistant_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["assistant_id", b"assistant_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListAssistantVersionsRequest = ListAssistantVersionsRequest

@typing.final
class AssistantVersion(google.protobuf.message.Message):
    """Represents a specific version of an assistant."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    ASSISTANT_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the assistant version."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Mask specifying which fields were updated in this version."""

    @property
    def assistant(self) -> yandex.cloud.ai.assistants.v1.assistant_pb2.Assistant:
        """Assistant configuration for this version."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        assistant: yandex.cloud.ai.assistants.v1.assistant_pb2.Assistant | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["assistant", b"assistant", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["assistant", b"assistant", "id", b"id", "update_mask", b"update_mask"]) -> None: ...

global___AssistantVersion = AssistantVersion

@typing.final
class ListAssistantVersionsResponse(google.protobuf.message.Message):
    """Response message containing the list versions operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token to retrieve the next page of results."""
    @property
    def versions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AssistantVersion]:
        """List of assistant versions."""

    def __init__(
        self,
        *,
        versions: collections.abc.Iterable[global___AssistantVersion] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "versions", b"versions"]) -> None: ...

global___ListAssistantVersionsResponse = ListAssistantVersionsResponse
